summaryrefslogtreecommitdiffstats
path: root/kmymoney2/mymoney/mymoneyexception.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/mymoney/mymoneyexception.h')
-rw-r--r--kmymoney2/mymoney/mymoneyexception.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/kmymoney2/mymoney/mymoneyexception.h b/kmymoney2/mymoney/mymoneyexception.h
index 68cf2af..41020b3 100644
--- a/kmymoney2/mymoney/mymoneyexception.h
+++ b/kmymoney2/mymoney/mymoneyexception.h
@@ -30,7 +30,7 @@
// ----------------------------------------------------------------------------
// QT Includes
-#include <qstring.h>
+#include <tqstring.h>
#include <kmymoney/export.h>
/**
* @file
@@ -57,8 +57,8 @@ public:
/**
* The constructor to create a new MyMoneyException object.
*
* @param msg reference to QString containing the message
* @param file reference to QString containing the name of the sourcefile where
* the exception was thrown
* @param line unsigned long containing the line number of the line where
* the exception was thrown in the file.
@@ -67,7 +67,7 @@ public:
* MYMONEYEXCEPTION(text) instead. It automatically assigns the file
* and line parameter to the correct values.
*/
- MyMoneyException(const QString& msg, const QString& file, const unsigned long line);
+ MyMoneyException(const TQString& msg, const TQString& file, const unsigned long line);
~MyMoneyException();
@@ -75,17 +75,17 @@ public:
* This method is used to return the message that was passed
* during the creation of the exception object.
*
* @return reference to QString containing the message
*/
- const QString& what(void) const { return m_msg; };
+ const TQString& what(void) const { return m_msg; };
/**
* This method is used to return the filename that was passed
* during the creation of the exception object.
*
* @return reference to QString containing the filename
*/
- const QString& file(void) const { return m_file; };
+ const TQString& file(void) const { return m_file; };
/**
* This method is used to return the linenumber that was passed
@@ -99,12 +99,12 @@ private:
/**
* This member variable holds the message
*/
- QString m_msg;
+ TQString m_msg;
/**
* This member variable holds the filename
*/
- QString m_file;
+ TQString m_file;
/**
* This member variable holds the line number
@@ -57,8 +57,8 @@ public:
* The constructor to create a new MyMoneyException object.
*
- * @param msg reference to QString containing the message
- * @param file reference to QString containing the name of the sourcefile where
+ * @param msg reference to TQString containing the message
+ * @param file reference to TQString containing the name of the sourcefile where
* the exception was thrown
* @param line unsigned long containing the line number of the line where
@@ -75,17 +75,17 @@ public:
* during the creation of the exception object.
*
- * @return reference to QString containing the message
+ * @return reference to TQString containing the message
*/
@@ -75,17 +75,17 @@ public:
* during the creation of the exception object.
*
- * @return reference to QString containing the filename
+ * @return reference to TQString containing the filename
*/